@@ -72,38 +72,39 @@ class AppProperties:
 
         return properties
 
-    @staticmethod
-    def load_cli_properties(option):
+    @classmethod
+    def load_cli_properties(cls, option):
         cli_properties = {}
 
-        if hasattr(option, 'set_url') and option.set_url:
+        if hasattr(option, 'set_url') and cls.__check_property_value(option.set_url):
             cli_properties['url'] = option.set_url
 
-        if hasattr(option, 'set_private_token') and option.set_private_token:
+        if hasattr(option, 'set_private_token') and cls.__check_property_value(option.set_private_token):
             cli_properties['privatetoken'] = option.set_private_token
 
-        if hasattr(option, 'set_project_id') and option.set_project_id:
+        if hasattr(option, 'set_project_id') and cls.__check_property_value(option.set_project_id):
             cli_properties['projectid'] = option.set_project_id
 
-        if hasattr(option, 'set_configuration_id') and option.set_configuration_id:
+        if hasattr(option, 'set_configuration_id') and cls.__check_property_value(option.set_configuration_id):
             cli_properties['configurationid'] = option.set_configuration_id
 
-        if hasattr(option, 'set_test_run_id') and option.set_test_run_id:
+        if hasattr(option, 'set_test_run_id') and cls.__check_property_value(option.set_test_run_id):
             cli_properties['testrunid'] = option.set_test_run_id
 
-        if hasattr(option, 'set_test_run_name') and option.set_test_run_name:
+        if hasattr(option, 'set_test_run_name') and cls.__check_property_value(option.set_test_run_name):
             cli_properties['testrunname'] = option.set_test_run_name
 
-        if hasattr(option, 'set_tms_proxy') and option.set_tms_proxy:
+        if hasattr(option, 'set_tms_proxy') and cls.__check_property_value(option.set_tms_proxy):
             cli_properties['tmsproxy'] = option.set_tms_proxy
 
-        if hasattr(option, 'set_adapter_mode') and option.set_adapter_mode:
+        if hasattr(option, 'set_adapter_mode') and cls.__check_property_value(option.set_adapter_mode):
             cli_properties['adaptermode'] = option.set_adapter_mode
 
-        if hasattr(option, 'set_cert_validation') and option.set_cert_validation:
+        if hasattr(option, 'set_cert_validation') and cls.__check_property_value(option.set_cert_validation):
             cli_properties['certvalidation'] = option.set_cert_validation
 
-        if hasattr(option, 'set_automatic_creation_test_cases') and option.set_automatic_creation_test_cases:
+        if hasattr(option, 'set_automatic_creation_test_cases') and cls.__check_property_value(
+                option.set_automatic_creation_test_cases):
             cli_properties['automaticcreationtestcases'] = option.set_automatic_creation_test_cases
 
         return cli_properties
@@ -112,34 +113,44 @@ class AppProperties:
     def load_env_properties(cls):
         env_properties = {}
 
-        if f'{cls.__env_prefix}_URL' in os.environ.keys():
+        if f'{cls.__env_prefix}_URL' in os.environ.keys() and cls.__check_property_value(
+                os.environ.get(f'{cls.__env_prefix}_URL')):
             env_properties['url'] = os.environ.get(f'{cls.__env_prefix}_URL')
 
-        if f'{cls.__env_prefix}_PRIVATE_TOKEN' in os.environ.keys():
+        if f'{cls.__env_prefix}_PRIVATE_TOKEN' in os.environ.keys() and cls.__check_property_value(
+                os.environ.get(f'{cls.__env_prefix}_PRIVATE_TOKEN')):
             env_properties['privatetoken'] = os.environ.get(f'{cls.__env_prefix}_PRIVATE_TOKEN')
 
-        if f'{cls.__env_prefix}_PROJECT_ID' in os.environ.keys():
+        if f'{cls.__env_prefix}_PROJECT_ID' in os.environ.keys() and cls.__check_property_value(
+                os.environ.get(f'{cls.__env_prefix}_PROJECT_ID')):
             env_properties['projectid'] = os.environ.get(f'{cls.__env_prefix}_PROJECT_ID')
 
-        if f'{cls.__env_prefix}_CONFIGURATION_ID' in os.environ.keys():
+        if f'{cls.__env_prefix}_CONFIGURATION_ID' in os.environ.keys() and cls.__check_property_value(
+                os.environ.get(f'{cls.__env_prefix}_CONFIGURATION_ID')):
             env_properties['configurationid'] = os.environ.get(f'{cls.__env_prefix}_CONFIGURATION_ID')
 
-        if f'{cls.__env_prefix}_TEST_RUN_ID' in os.environ.keys():
+        if f'{cls.__env_prefix}_TEST_RUN_ID' in os.environ.keys() and cls.__check_property_value(
+                os.environ.get(f'{cls.__env_prefix}_TEST_RUN_ID')):
             env_properties['testrunid'] = os.environ.get(f'{cls.__env_prefix}_TEST_RUN_ID')
 
-        if f'{cls.__env_prefix}_TEST_RUN_NAME' in os.environ.keys():
+        if f'{cls.__env_prefix}_TEST_RUN_NAME' in os.environ.keys() and cls.__check_property_value(
+                os.environ.get(f'{cls.__env_prefix}_TEST_RUN_NAME')):
             env_properties['testrunname'] = os.environ.get(f'{cls.__env_prefix}_TEST_RUN_NAME')
 
-        if f'{cls.__env_prefix}_PROXY' in os.environ.keys():
+        if f'{cls.__env_prefix}_PROXY' in os.environ.keys() and cls.__check_property_value(
+                os.environ.get(f'{cls.__env_prefix}_PROXY')):
             env_properties['tmsproxy'] = os.environ.get(f'{cls.__env_prefix}_PROXY')
 
-        if f'{cls.__env_prefix}_ADAPTER_MODE' in os.environ.keys():
+        if f'{cls.__env_prefix}_ADAPTER_MODE' in os.environ.keys() and cls.__check_property_value(
+                os.environ.get(f'{cls.__env_prefix}_ADAPTER_MODE')):
             env_properties['adaptermode'] = os.environ.get(f'{cls.__env_prefix}_ADAPTER_MODE')
 
-        if f'{cls.__env_prefix}_CERT_VALIDATION' in os.environ.keys():
+        if f'{cls.__env_prefix}_CERT_VALIDATION' in os.environ.keys() and cls.__check_property_value(
+                os.environ.get(f'{cls.__env_prefix}_CERT_VALIDATION')):
             env_properties['certvalidation'] = os.environ.get(f'{cls.__env_prefix}_CERT_VALIDATION')
 
-        if f'{cls.__env_prefix}_AUTOMATIC_CREATION_TEST_CASES' in os.environ.keys():
+        if f'{cls.__env_prefix}_AUTOMATIC_CREATION_TEST_CASES' in os.environ.keys() and cls.__check_property_value(
+                os.environ.get(f'{cls.__env_prefix}_AUTOMATIC_CREATION_TEST_CASES')):
             env_properties['automaticcreationtestcases'] = os.environ.get(
                 f'{cls.__env_prefix}_AUTOMATIC_CREATION_TEST_CASES')
 
@@ -192,3 +203,10 @@ class AppProperties:
             return os.environ[var_name[1:-1]]
 
         return var_name
+
+    @staticmethod
+    def __check_property_value(value: str):
+        if value is not None and value != "":
+            return True
+
+        return False
